# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc51
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class V1CronSchedule(BaseModel):
    """
    V1CronSchedule
    """
    kind: Optional[StrictStr] = 'cron'
    start_at: Optional[datetime] = Field(None, alias="startAt")
    end_at: Optional[datetime] = Field(None, alias="endAt")
    max_runs: Optional[StrictInt] = Field(None, alias="maxRuns")
    cron: Optional[StrictStr] = None
    depends_on_past: Optional[StrictBool] = Field(None, alias="dependsOnPast")
    __properties = ["kind", "startAt", "endAt", "maxRuns", "cron", "dependsOnPast"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CronSchedule:
        """Create an instance of V1CronSchedule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CronSchedule:
        """Create an instance of V1CronSchedule from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1CronSchedule.parse_obj(obj)

        _obj = V1CronSchedule.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'cron',
            "start_at": obj.get("startAt"),
            "end_at": obj.get("endAt"),
            "max_runs": obj.get("maxRuns"),
            "cron": obj.get("cron"),
            "depends_on_past": obj.get("dependsOnPast")
        })
        return _obj

